/*
 *  GOL - Game of life simulation software
 *  Copyright (C) 1996 Michael Raymond Brown
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Michael Raymond Brown
 *  EMail:  michael@arrakeen.demon.co.uk
 *  WWW:    http://www.arrakeen.demon.co.uk/
 *  Address:  Michael Brown
 *            Kia Ora
 *            Brook Street
 *            Great Bromley
 *            Nr Colchester
 *            Essex
 *            CO7 7HX
 *            England
 */


#ifdef __GNUC__
#pragma implementation
#endif

#include "DrawArea.h"
#include "Image.h"

Display* xwDrawArea::getDisplay()
   {if (!display) display = XtDisplay(widget);
    return display;
   }
Window xwDrawArea::getWindow()
   {if (!window) window = XtWindow(widget);
    return window;
   }
GC xwDrawArea::getGC()
   {
    XGCValues gc_val;

    if (!display) display = XtDisplay(widget);
    if (!window) window = XtWindow(widget);
    if (!gc)
       {
	gc_val.function=GXcopy;
	gc_val.foreground=WhitePixel(display, DefaultScreen(display));
	gc_val.background=BlackPixel(display, DefaultScreen(display));
	gc_val.graphics_exposures=False;
	gc=XCreateGC(display, window, GCFunction|GCForeground|GCBackground|GCGraphicsExposures,&gc_val);
       }
    return gc;
   }

void xwDrawArea::init()
   {
    display = (Display*)0;
    window = 0;
    gc = 0;

    default_callbacks(evnt_Expose|evnt_Motion, meth_Size|meth_Close);
    linkParent(parent);
   }

xwDrawArea::xwDrawArea(xwWidget* p, int x1, int y1, int x2, int y2)
   {
    parent = p;
    widget = XtVaCreateManagedWidget("label"
		, xmDrawingAreaWidgetClass, parent->getWidget()

		, XmNleftAttachment,	XmATTACH_POSITION
		, XmNrightAttachment,	XmATTACH_POSITION
		, XmNtopAttachment,	XmATTACH_POSITION
		, XmNbottomAttachment,	XmATTACH_POSITION

		, XmNleftPosition,	x1
		, XmNrightPosition,	x2
		, XmNtopPosition,	y1
		, XmNbottomPosition,	y2

		, 0);
    init();
   }
xwDrawArea::xwDrawArea(xwWidget* p, int w, int h)
   {
    parent = p;
    widget = XtVaCreateManagedWidget("label"
		, xmDrawingAreaWidgetClass, parent->getWidget()
		, XmNwidth, w, XmNheight, h
		, 0);
    init();
   }
xwDrawArea::~xwDrawArea()
   {if (gc) XFreeGC(display, gc);
   }



void xwDrawArea::plot(int x, int y, int colour)
   {getGC();
    XSetForeground(display, gc, colour);
    XDrawPoint(display, window, gc, x, y);
   }
int xwDrawArea::point(int x, int y)
   {return 0;
   }

void xwDrawArea::line(int x1, int y1, int x2, int y2, int colour)
   {getGC();
    XSetForeground(display, gc, colour);
    XDrawLine(display, window, gc, x1, y1, x2, y2);
   }

void xwDrawArea::clear()
   {XClearArea(getDisplay(), getWindow(), 0, 0, 0, 0, True);
   }

